@@ -121,47 +121,12 @@ pub trait ElementImpl: ElementImplExt + GstObjectImpl + Send + Sync {
     }
 }
 
-pub trait ElementImplExt: ObjectSubclass {
-    fn parent_change_state(
-        &self,
-        transition: StateChange,
-    ) -> Result<StateChangeSuccess, StateChangeError>;
-
-    fn parent_request_new_pad(
-        &self,
-        templ: &crate::PadTemplate,
-        name: Option<&str>,
-        caps: Option<&crate::Caps>,
-    ) -> Option<crate::Pad>;
-
-    fn parent_release_pad(&self, pad: &crate::Pad);
-
-    fn parent_send_event(&self, event: Event) -> bool;
-
-    fn parent_query(&self, query: &mut QueryRef) -> bool;
-
-    fn parent_set_context(&self, context: &crate::Context);
-
-    fn parent_set_clock(&self, clock: Option<&crate::Clock>) -> bool;
-
-    fn parent_provide_clock(&self) -> Option<crate::Clock>;
-
-    fn parent_post_message(&self, msg: crate::Message) -> bool;
-
-    fn panicked(&self) -> &atomic::AtomicBool;
-
-    fn catch_panic<R, F: FnOnce(&Self) -> R, G: FnOnce() -> R>(&self, fallback: G, f: F) -> R;
-
-    fn catch_panic_pad_function<R, F: FnOnce(&Self) -> R, G: FnOnce() -> R>(
-        parent: Option<&crate::Object>,
-        fallback: G,
-        f: F,
-    ) -> R;
-
-    fn post_error_message(&self, msg: crate::ErrorMessage);
+mod sealed {
+    pub trait Sealed {}
+    impl<T: super::ElementImplExt> Sealed for T {}
 }
 
-impl<T: ElementImpl> ElementImplExt for T {
+pub trait ElementImplExt: sealed::Sealed + ObjectSubclass {
     fn parent_change_state(
         &self,
         transition: StateChange,
@@ -349,6 +314,8 @@ impl<T: ElementImpl> ElementImplExt for T {
     }
 }
 
+impl<T: ElementImpl> ElementImplExt for T {}
+
 unsafe impl<T: ElementImpl> IsSubclassable<T> for Element {
     fn class_init(klass: &mut glib::Class<Self>) {
         Self::parent_class_init::<T>(klass);
@@ -584,7 +551,7 @@ mod tests {
 
             fn with_class(klass: &Self::Class) -> Self {
                 let templ = klass.pad_template("sink").unwrap();
-                let sinkpad = crate::Pad::builder_with_template(&templ, Some("sink"))
+                let sinkpad = crate::Pad::builder_from_template(&templ)
                     .chain_function(|pad, parent, buffer| {
                         TestElement::catch_panic_pad_function(
                             parent,
@@ -609,7 +576,7 @@ mod tests {
                     .build();
 
                 let templ = klass.pad_template("src").unwrap();
-                let srcpad = crate::Pad::builder_with_template(&templ, Some("src"))
+                let srcpad = crate::Pad::builder_from_template(&templ)
                     .event_function(|pad, parent, event| {
                         TestElement::catch_panic_pad_function(
                             parent,
@@ -649,7 +616,7 @@ mod tests {
 
         impl ElementImpl for TestElement {
             fn metadata() -> Option<&'static ElementMetadata> {
-                use once_cell::sync::Lazy;
+                use glib::once_cell::sync::Lazy;
                 static ELEMENT_METADATA: Lazy<ElementMetadata> = Lazy::new(|| {
                     ElementMetadata::new(
                         "Test Element",
@@ -663,7 +630,7 @@ mod tests {
             }
 
             fn pad_templates() -> &'static [PadTemplate] {
-                use once_cell::sync::Lazy;
+                use glib::once_cell::sync::Lazy;
                 static PAD_TEMPLATES: Lazy<Vec<PadTemplate>> = Lazy::new(|| {
                     let caps = crate::Caps::new_any();
                     vec![
@@ -725,7 +692,7 @@ mod tests {
             Some("Test Element")
         );
 
-        let pipeline = crate::Pipeline::new(None);
+        let pipeline = crate::Pipeline::new();
         let src = ElementFactory::make("fakesrc")
             .property("num-buffers", 100i32)
             .build()
@@ -733,9 +700,9 @@ mod tests {
         let sink = ElementFactory::make("fakesink").build().unwrap();
 
         pipeline
-            .add_many(&[&src, element.upcast_ref(), &sink])
+            .add_many([&src, element.upcast_ref(), &sink])
             .unwrap();
-        Element::link_many(&[&src, element.upcast_ref(), &sink]).unwrap();
+        Element::link_many([&src, element.upcast_ref(), &sink]).unwrap();
 
         pipeline.set_state(crate::State::Playing).unwrap();
         let bus = pipeline.bus().unwrap();
